@@ -1,6 +1,6 @@
-/* $Id: main.c,v 1.60 2003/10/21 00:28:36 nlevitt Exp $ */
+/* $Id: main.c,v 1.69 2004/02/02 00:48:05 nlevitt Exp $ */
 /*
- * Copyright (c) 2003  Noah Levitt <nlevitt аt users.sourceforge.net>
+ * Copyright (c) 2004 Noah Levitt
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -17,9 +17,7 @@
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
+#include "config.h"
 
 #include <gtk/gtk.h>
 #include <stdlib.h>
@@ -30,9 +28,9 @@
 #if !HAVE_GNOME
 # include <popt.h>
 #endif
-#include <gucharmap/gucharmap.h>
-#include <gucharmap/gucharmap_intl.h>
-
+#include "gucharmap-intl.h"
+#include "gucharmap-window.h"
+#include "gucharmap-mini-fontsel.h"
 
 static gchar *new_font = NULL;
 static struct poptOption options[] = 
@@ -45,16 +43,13 @@ static struct poptOption options[] =
   { NULL, '\0', 0, NULL, 0 }
 };
 
-
 gint
 main (gint argc, gchar **argv)
 {
   GtkWidget *window;
-  gchar *orig_font = NULL;
-  PangoFontDescription *font_desc = NULL;
   GdkScreen *screen;
   gint monitor;
-    GdkRectangle rect;
+  GdkRectangle rect;
 #if !HAVE_GNOME
   poptContext popt_context;
   gint rc;
@@ -71,19 +66,15 @@ main (gint argc, gchar **argv)
 
 #if HAVE_GNOME
   gnome_program_init ("gucharmap", VERSION, LIBGNOMEUI_MODULE, argc, argv,
-                      GNOME_PARAM_APP_DATADIR, DATADIR,     
+                      GNOME_PARAM_APP_DATADIR, DATADIR,
                       GNOME_PARAM_POPT_TABLE, options, NULL);
 #else
-  popt_context = poptGetContext ("gucharmap", argc, (const gchar **) argv, 
-                                 options, 0);
+  popt_context = poptGetContext ("gucharmap", argc, (const gchar **) argv, options, 0);
   rc = poptGetNextOpt (popt_context);
 
   if (rc != -1)
     {
-       g_printerr ("%s: %s\n", 
-                   poptBadOption (popt_context, POPT_BADOPTION_NOALIAS),
-                   poptStrerror (rc));
-
+       g_printerr ("%s: %s\n", poptBadOption (popt_context, POPT_BADOPTION_NOALIAS), poptStrerror (rc));
        exit (1);
     }
 #endif  /* else (#if HAVE_GNOME) */
@@ -96,27 +87,22 @@ main (gint argc, gchar **argv)
   screen = gtk_window_get_screen (GTK_WINDOW (window));
   monitor = gdk_screen_get_monitor_at_point (screen, 0, 0);
   gdk_screen_get_monitor_geometry (screen, monitor, &rect);
-  gtk_window_set_default_size (GTK_WINDOW (window), 
-                               rect.width * 9/16, 
-                               rect.height * 9/16);
+  gtk_window_set_default_size (GTK_WINDOW (window), rect.width * 9/16, rect.height * 9/16);
 
   /* make the starting font 50% bigger than the default font */
   if (new_font == NULL) /* new_font could be set by command line option */
     {
-      orig_font = gucharmap_mini_font_selection_get_font_name (GUCHARMAP_MINI_FONT_SELECTION (GUCHARMAP_WINDOW (window)->fontsel));
-
-      font_desc = pango_font_description_from_string (orig_font);
-      pango_font_description_set_size (font_desc, pango_font_description_get_size (font_desc) * 3/2 / PANGO_SCALE * PANGO_SCALE);
-      new_font = pango_font_description_to_string (font_desc);
+      GucharmapMiniFontSelection *fontsel = gucharmap_window_get_mini_font_selection (GUCHARMAP_WINDOW (window));
+      gint default_size = PANGO_PIXELS (2.0 * pango_font_description_get_size (window->style->font_desc));
+      gucharmap_mini_font_selection_set_default_font_size (fontsel, default_size);
+      gucharmap_mini_font_selection_reset_font_size (fontsel);
     }
-  /* this sends the changed signal: */
-  gucharmap_mini_font_selection_set_font_name (GUCHARMAP_MINI_FONT_SELECTION (GUCHARMAP_WINDOW (window)->fontsel), new_font);
 
-  g_signal_connect (G_OBJECT (window), "destroy", 
-                    G_CALLBACK (gtk_main_quit), NULL);
+  g_signal_connect (G_OBJECT (window), "destroy", G_CALLBACK (gtk_main_quit), NULL);
 
   gucharmap_table_grab_focus (GUCHARMAP_WINDOW (window)->charmap->chartable);
-  gtk_widget_show_all (window);
+
+  gtk_widget_show (window);
 
   gtk_main ();
 
